@@ -211,11 +211,11 @@
 #' plot(fitd)
 #'
 #' @importFrom survival survdiff Surv cluster
-#' @importFrom KernSmooth dpik
 #' @importFrom stats quantile
 #' @import lava
 #' @useDynLib prodlim
 #' @export
+## --> import From KernSmooth dpik
 "prodlim" <- function(formula,
                       data = parent.frame(),
                       subset,
@@ -261,7 +261,9 @@
   if (match("Surv",class(response),nomatch=0)!=0){
       attr(response,"model") <- "survival"
       attr(response,"cens.type") <- "rightCensored"
-      ## attr(response,"entry.type") <- ""
+      attr(response,"entry.type") <- ifelse(ncol(response)==2,"","leftTruncated")
+      if (attr(response,"entry.type")=="leftTruncated")
+          colnames(response) <- c("entry","time","status")
       model.type <- 1
   }
   else{
@@ -368,7 +370,8 @@
   
   # }}}
   # {{{ delay (left truncation)
-  delayed <- !(is.null(attr(event.history,"entry.type"))) && !(attr(event.history,"entry.type")=="")
+  delayed <- attr(event.history,"entry.type")=="leftTruncated"
+  ## && !(attr(event.history,"entry.type")=="")
   if (!delayed) { ## either NULL or ""
       entrytime <- NULL
   }  else {
@@ -505,7 +508,7 @@
       # {{{  two state model
       if (clustered){
           ## right censored clustered
-          fit <- .C("prodlim",as.double(response[,"time"]),as.double(response[,"status"]),integer(0),as.double(entrytime),as.double(caseweights),as.integer(cluster),as.integer(N),integer(0),as.integer(NC),as.integer(NU),as.integer(size.strata),time=double(N),nrisk=double(2*N),nevent=double(2*N),ncens=double(2*N),surv=double(N),cuminc=double(0),hazard=double(N),var.hazard=double(N+N),extra.double=double(4 * max(NC)),max.nc=as.integer(max(NC)),ntimes=integer(1),ntimes.strata=integer(NU),first.strata=integer(NU),reverse=integer(0),model=as.integer(0),independent=as.integer(0),delayed=as.integer(delayed),weighted=as.integer(weighted),DUP=TRUE,PACKAGE="prodlim")
+          fit <- .C("prodlim",as.double(response[,"time"]),as.double(response[,"status"]),integer(0),as.double(entrytime),as.double(caseweights),as.integer(cluster),as.integer(N),integer(0),as.integer(NC),as.integer(NU),as.integer(size.strata),time=double(N),nrisk=double(2*N),nevent=double(2*N),ncens=double(2*N),surv=double(N),cuminc=double(0),hazard=double(N),var.hazard=double(N+N),extra.double=double(4 * max(NC)),max.nc=as.integer(max(NC)),ntimes=integer(1),ntimes.strata=integer(NU),first.strata=integer(NU),reverse=integer(0),model=as.integer(0),independent=as.integer(0),delayed=as.integer(delayed),weighted=as.integer(weighted),PACKAGE="prodlim")
           NT <- fit$ntimes
           Cout <- list("time"=fit$time[1:NT],"n.risk"=matrix(fit$nrisk,ncol=2,byrow=FALSE,dimnames=list(NULL,c("n.risk","cluster.n.risk")))[1:NT,],"n.event"=matrix(fit$nevent,ncol=2,byrow=FALSE,dimnames=list(NULL,c("n.event","cluster.n.event")))[1:NT,],"n.lost"=matrix(fit$ncens,ncol=2,byrow=FALSE,dimnames=list(NULL,c("n.lost","cluster.n.lost")))[1:NT,],"surv"=fit$surv[1:NT],"se.surv"=fit$surv[1:NT]*sqrt(pmax(0,fit$var.hazard[N+(1:NT)])),"naive.se.surv"=fit$surv[1:NT]*sqrt(pmax(0,fit$var.hazard[1:NT])),"hazard"=fit$hazard[1:NT],"first.strata"=fit$first.strata,"size.strata"=fit$ntimes.strata,"model"="survival")
           Cout$maxtime <- max(Cout$time)
@@ -529,7 +532,7 @@
           }
           else{
               ## right censored not clustered
-              fit <- .C("prodlim",as.double(response[,"time"]),as.double(response[,"status"]),integer(0),as.double(entrytime),as.double(caseweights),integer(0),as.integer(N),integer(0),integer(0),as.integer(NU),as.integer(size.strata),time=double(N),nrisk=double(N),nevent=double(N),ncens=double(N),surv=double(N),double(0),hazard = double(N),var.hazard=double(N),extra.double=double(0),max.nc=integer(0),ntimes=integer(1),ntimes.strata=integer(NU),first.strata=integer(NU),as.integer(reverse),model=as.integer(0),independent=as.integer(1),delayed=as.integer(delayed),weighted=as.integer(weighted),DUP=TRUE,PACKAGE="prodlim")
+              fit <- .C("prodlim",as.double(response[,"time"]),as.double(response[,"status"]),integer(0),as.double(entrytime),as.double(caseweights),integer(0),as.integer(N),integer(0),integer(0),as.integer(NU),as.integer(size.strata),time=double(N),nrisk=double(N),nevent=double(N),ncens=double(N),surv=double(N),double(0),hazard = double(N),var.hazard=double(N),extra.double=double(0),max.nc=integer(0),ntimes=integer(1),ntimes.strata=integer(NU),first.strata=integer(NU),as.integer(reverse),model=as.integer(0),independent=as.integer(1),delayed=as.integer(delayed),weighted=as.integer(weighted),PACKAGE="prodlim")
               NT <- fit$ntimes
               Cout <- list("time"=fit$time[1:NT],
                            "n.risk"=fit$nrisk[1:NT],
@@ -583,7 +586,6 @@
                     independent=as.integer(1),
                     delayed=as.integer(delayed),
                     weighted=as.integer(weighted),
-                    DUP=TRUE,
                     PACKAGE="prodlim")
           NT <- fit$ntimes
           # changed Tue Sep 30 12:51:58 CEST 2008
